import { NetworkInterface } from './networkInterface';
import { ApolloStore, Store } from './store';
import { QueryStoreValue } from './queries/store';
import { QueryTransformer } from './queries/queryTransform';
import { NormalizedCache } from './data/store';
import { Document, FragmentDefinition } from 'graphql';
import { MutationBehavior } from './data/mutationResults';
import { ApolloQueryResult } from './index';
import { Observable, Observer, Subscription, SubscriberFunction } from './util/Observable';
export declare class ObservableQuery extends Observable<ApolloQueryResult> {
    refetch: (variables?: any) => Promise<ApolloQueryResult>;
    stopPolling: () => void;
    startPolling: (p: number) => void;
    constructor(options: {
        subscriberFunction: SubscriberFunction<ApolloQueryResult>;
        refetch: (variables?: any) => Promise<ApolloQueryResult>;
        stopPolling: () => void;
        startPolling: (p: number) => void;
    });
    subscribe(observer: Observer<ApolloQueryResult>): Subscription;
    result(): Promise<ApolloQueryResult>;
}
export interface WatchQueryOptions {
    query: Document;
    variables?: {
        [key: string]: any;
    };
    forceFetch?: boolean;
    returnPartialData?: boolean;
    pollInterval?: number;
    fragments?: FragmentDefinition[];
}
export declare type QueryListener = (queryStoreValue: QueryStoreValue) => void;
export declare class QueryManager {
    private networkInterface;
    private store;
    private reduxRootKey;
    private pollingTimers;
    private queryTransformer;
    private queryListeners;
    private idCounter;
    private scheduler;
    private batcher;
    private batcherPollInterval;
    private fetchQueryPromises;
    private observableQueries;
    constructor({networkInterface, store, reduxRootKey, queryTransformer, shouldBatch}: {
        networkInterface: NetworkInterface;
        store: ApolloStore;
        reduxRootKey: string;
        queryTransformer?: QueryTransformer;
        shouldBatch?: Boolean;
    });
    broadcastNewStore(store: any): void;
    mutate({mutation, variables, resultBehaviors, fragments, optimisticResponse}: {
        mutation: Document;
        variables?: Object;
        resultBehaviors?: MutationBehavior[];
        fragments?: FragmentDefinition[];
        optimisticResponse?: Object;
    }): Promise<ApolloQueryResult>;
    queryListenerForObserver(options: WatchQueryOptions, observer: Observer<ApolloQueryResult>): QueryListener;
    watchQuery(options: WatchQueryOptions, shouldSubscribe?: boolean): ObservableQuery;
    query(options: WatchQueryOptions): Promise<ApolloQueryResult>;
    fetchQuery(queryId: string, options: WatchQueryOptions): Promise<ApolloQueryResult>;
    generateQueryId(): string;
    stopQueryInStore(queryId: string): void;
    getApolloState(): Store;
    getDataWithOptimisticResults(): NormalizedCache;
    addQueryListener(queryId: string, listener: QueryListener): void;
    removeQueryListener(queryId: string): void;
    addFetchQueryPromise(requestId: number, promise: Promise<ApolloQueryResult>, resolve: (result: ApolloQueryResult) => void, reject: (error: Error) => void): void;
    removeFetchQueryPromise(requestId: number): void;
    addObservableQuery(queryId: string, observableQuery: ObservableQuery): void;
    addQuerySubscription(queryId: string, querySubscription: Subscription): void;
    removeObservableQuery(queryId: string): void;
    resetStore(): void;
    private fetchQueryOverInterface(queryId, options, network);
    private startQuery(queryId, options, listener);
    private stopQuery(queryId);
    private broadcastQueries();
    private generateRequestId();
}
